@@ -46,7 +46,7 @@ from .derangements import Derangements
 lazy_import('sage.combinat.baxter_permutations', ['BaxterPermutations'])
 
 #RSK
-from .rsk import RSK, RSK_inverse, robinson_schensted_knuth, robinson_schensted_knuth_inverse
+from .rsk import RSK, RSK_inverse, robinson_schensted_knuth, robinson_schensted_knuth_inverse, InsertionRules
 
 #HillmanGrassl
 lazy_import("sage.combinat.hillman_grassl", ["WeakReversePlanePartition", "WeakReversePlanePartitions"])
@@ -105,6 +105,9 @@ lazy_import('sage.combinat.lr_tableau', ['LittlewoodRichardsonTableau',
 lazy_import('sage.combinat.shifted_primed_tableau', ['ShiftedPrimedTableaux',
                                                      'ShiftedPrimedTableau'])
 
+#SuperTableaux
+lazy_import('sage.combinat.super_tableau',["StandardSuperTableau", "SemistandardSuperTableau", "StandardSuperTableaux", "SemistandardSuperTableaux"])
+
 #Words
 from .words.all import *
 
@@ -115,11 +118,16 @@ from .graph_path import GraphPaths
 #Tuples
 from .tuple import Tuples, UnorderedTuples
 
-#Alternating sign matrices
-from .alternating_sign_matrix import AlternatingSignMatrix, AlternatingSignMatrices, MonotoneTriangles, ContreTableaux, TruncatedStaircases
+# Alternating sign matrices
+lazy_import('sage.combinat.alternating_sign_matrix', ('AlternatingSignMatrix',
+                                                      'AlternatingSignMatrices',
+                                                      'MonotoneTriangles',
+                                                      'ContreTableaux',
+                                                      'TruncatedStaircases'))
 
-#Plane Partitions
-from .plane_partition import PlanePartition, PlanePartitions
+# Plane Partitions
+lazy_import('sage.combinat.plane_partition', ('PlanePartition',
+                                              'PlanePartitions'))
 
 # Parking Functions
 lazy_import('sage.combinat.non_decreasing_parking_function',
@@ -132,10 +140,9 @@ from .ordered_tree import (OrderedTree, OrderedTrees,
                           LabelledOrderedTree, LabelledOrderedTrees)
 from .binary_tree import (BinaryTree, BinaryTrees,
                          LabelledBinaryTree, LabelledBinaryTrees)
-
 lazy_import('sage.combinat.interval_posets', ['TamariIntervalPoset', 'TamariIntervalPosets'])
-from .rooted_tree import (RootedTree, RootedTrees,
-                         LabelledRootedTree, LabelledRootedTrees)
+lazy_import('sage.combinat.rooted_tree', ('RootedTree', 'RootedTrees',
+                         'LabelledRootedTree', 'LabelledRootedTrees'))
 
 from .combination import Combinations
 from .cartesian_product import CartesianProduct
@@ -147,10 +154,10 @@ lazy_import('sage.combinat.multiset_partition_into_sets_ordered', ['OrderedMulti
 from .subset import Subsets
 #from subsets_pairwise import PairwiseCompatibleSubsets
 from .necklace import Necklaces
-from .lyndon_word import LyndonWord, LyndonWords, StandardBracketedLyndonWords
-from .dyck_word import DyckWords, DyckWord
+lazy_import('sage.combinat.dyck_word', ('DyckWords', 'DyckWord'))
 from .sloane_functions import sloane
-from .superpartition import SuperPartition, SuperPartitions
+lazy_import('sage.combinat.superpartition', ('SuperPartition',
+                                             'SuperPartitions'))
 
 lazy_import('sage.combinat.parallelogram_polyomino',
             ['ParallelogramPolyomino', 'ParallelogramPolyominoes'])
@@ -173,7 +180,7 @@ from .integer_vector import IntegerVectors
 from .integer_vector_weighted import WeightedIntegerVectors
 from .integer_vectors_mod_permgroup import IntegerVectorsModPermutationGroup
 
-from .q_analogues import gaussian_binomial, q_binomial
+lazy_import('sage.combinat.q_analogues', ['gaussian_binomial', 'q_binomial'])
 
 from .species.all import *
 
@@ -198,6 +205,7 @@ lazy_import('sage.combinat.finite_state_machine',
             ['Automaton', 'Transducer', 'FiniteStateMachine'])
 lazy_import('sage.combinat.finite_state_machine_generators',
             ['automata', 'transducers'])
+
 # Binary Recurrence Sequences
 lazy_import('sage.combinat.binary_recurrence_sequences',
             'BinaryRecurrenceSequence')
