@@ -34,7 +34,7 @@ while the full version has the layout::
     CREATE INDEX i_t_class_conductor ON t_class(conductor);
     CREATE INDEX i_t_curve_class ON t_curve(class);
 """
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2014 John Cremona <john.cremona@gmail.com>
 #       Copyright (C) 2011 R. Andrew Ohana <andrew.ohana@gmail.com>
 #       Copyright (C) 2005 William Stein <wstein@gmail.com>
@@ -42,11 +42,9 @@ while the full version has the layout::
 #  Distributed under the terms of the GNU General Public License (GPL)
 #  as published by the Free Software Foundation; either version 2 of
 #  the License, or (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
-
-from __future__ import print_function
-from __future__ import absolute_import
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
+from __future__ import print_function, absolute_import
 
 import os
 from sage.misc.prandom import randint
@@ -54,7 +52,7 @@ from sage.misc.prandom import randint
 import sage.schemes.elliptic_curves.constructor as elliptic
 from .sql_db import SQLDatabase, verify_column
 from sage.features.databases import DatabaseCremona
-from sage.env import CREMONA_MINI_DATA_DIR, CREMONA_LARGE_DATA_DIR
+from sage.env import CREMONA_MINI_DATA_DIR, CREMONA_LARGE_DATA_DIR, SAGE_SHARE
 from sage.misc.all import walltime
 
 import re
@@ -100,6 +98,7 @@ for t in _cremonaSkeleton:
     for c in _miniCremonaSkeleton[t]:
         _miniCremonaSkeleton[t][c] = verify_column(_miniCremonaSkeleton[t][c])
 
+
 def build(name, data_tgz, largest_conductor=0, mini=False, decompress=True):
     """
     Build the CremonaDatabase with given name from scratch
@@ -119,7 +118,7 @@ def build(name, data_tgz, largest_conductor=0, mini=False, decompress=True):
     """
     db_path = os.path.join(SAGE_SHARE,'cremona',name.replace(' ','_')+'.db')
     if os.path.exists(db_path):
-        raise RuntimeError('Please (re)move %s before building '%db_path \
+        raise RuntimeError('Please (re)move %s before building ' % db_path \
                 + 'database')
     if not os.path.exists(data_tgz):
         raise IOError("The data file is not at %s"%data_tgz)
@@ -139,10 +138,13 @@ def build(name, data_tgz, largest_conductor=0, mini=False, decompress=True):
     c._init_from_ftpdata('ecdata', largest_conductor)
     print("Total time: ", walltime(t))
 
+
 def is_optimal_id(id):
     """
-    Returns true if the Cremona id refers to an optimal curve, and
-    false otherwise. The curve is optimal if the id, which is of the
+    Return True if the Cremona id refers to an optimal curve, and
+    false otherwise.
+
+    The curve is optimal if the id, which is of the
     form [letter code][number] has number 1.
 
     .. note::
@@ -171,10 +173,12 @@ def is_optimal_id(id):
     """
     return id[-1] == '1' and not id[-2].isdigit()
 
+
 def cremona_letter_code(n):
     """
-    Returns the Cremona letter code corresponding to an integer. For
-    example, 0 - a 25 - z 26 - ba 51 - bz 52 - ca 53 - cb etc.
+    Return the Cremona letter code corresponding to an integer.
+
+    For example, 0 - a 25 - z 26 - ba 51 - bz 52 - ca 53 - cb etc.
 
     .. note::
 
@@ -233,7 +237,7 @@ def cremona_letter_code(n):
     except (ValueError, TypeError):
         n = -1
 
-    if n<0:
+    if n < 0:
         raise ValueError("Cremona letter codes are only defined for non-negative integers")
 
     if n == 0:
@@ -244,10 +248,10 @@ def cremona_letter_code(n):
         n //= 26
     return s
 
+
 def old_cremona_letter_code(n):
     r"""
-    Returns the *old* Cremona letter code corresponding to an integer.
-    integer.
+    Return the *old* Cremona letter code corresponding to an integer.
 
     For example::
 
@@ -285,10 +289,12 @@ def old_cremona_letter_code(n):
     label = chr(k)*int(n//26 + 1)
     return label
 
+
 old_cremona_label_regex = re.compile(r'(\d+)([A-Z]*)(\d*)$')
 cremona_label_regex = re.compile(r'(\d+)([a-z]*)(\d*)$')
 lmfdb_label_regex = re.compile(r'(\d+)\.([a-z]+)(\d*)$')
 
+
 def parse_cremona_label(label):
     """
     Given a Cremona label that defines an elliptic
@@ -362,10 +368,11 @@ def parse_cremona_label(label):
 
     # verify cremona label is valid
     if iso.lower() != iso:
-        raise ValueError('%s is not a valid Cremona label'%label)
+        raise ValueError('%s is not a valid Cremona label' % label)
 
     return int(conductor), iso, int(num)
 
+
 def parse_lmfdb_label(label):
     """
     Given an LMFDB label that defines an elliptic curve, e.g., 11.a1
@@ -424,9 +431,10 @@ def parse_lmfdb_label(label):
 
 _class_curve_re = re.compile(r'(?P<class>[a-z]+)(?P<curve>\d+)')
 
+
 def split_code(key):
     """
-    Splits class + curve id string into its two parts.
+    Split class + curve id string into its two parts.
 
     EXAMPLES::
 
@@ -438,7 +446,6 @@ def split_code(key):
         ...
         ValueError: invalid curve ID: '42'
     """
-
     m = _class_curve_re.match(key)
 
     if not m:
@@ -449,8 +456,9 @@ def split_code(key):
 
 def class_to_int(k):
     """
-    Converts class id string into an integer. Note that this is the
-    inverse of cremona_letter_code.
+    Convert class id string into an integer.
+
+    Note that this is the inverse of :func:`cremona_letter_code`.
 
     EXAMPLES::
 
@@ -464,7 +472,7 @@ def class_to_int(k):
     """
     kk = [string.ascii_lowercase.index(ch) for ch in list(k)]
     kk.reverse()
-    return sum([kk[i] * 26 ** i for i in range(len(kk))])
+    return sum(kk[i] * 26 ** i for i in range(len(kk)))
 
 
 def sort_key(key1):
@@ -488,7 +496,7 @@ def sort_key(key1):
 
 def cremona_to_lmfdb(cremona_label, CDB=None):
     """
-    Converts a Cremona label into an LMFDB label.
+    Convert a Cremona label into an LMFDB label.
 
     See :func:`parse_lmfdb_label` for an explanation of LMFDB labels.
 
@@ -545,9 +553,10 @@ def cremona_to_lmfdb(cremona_label, CDB=None):
     else:
         return N + '.' + lmfdb_iso
 
+
 def lmfdb_to_cremona(lmfdb_label, CDB=None):
     """
-    Converts an LMFDB labe into a Cremona label.
+    Convert an LMFDB labe into a Cremona label.
 
     See :func:`parse_lmfdb_label` for an explanation of LMFDB labels.
 
@@ -595,6 +604,7 @@ def lmfdb_to_cremona(lmfdb_label, CDB=None):
     else:
         return N + cremona_iso
 
+
 class MiniCremonaDatabase(SQLDatabase):
     """
     The Cremona database of elliptic curves.
@@ -629,16 +639,16 @@ class MiniCremonaDatabase(SQLDatabase):
                     skeleton=_miniCremonaSkeleton)
             return
         if not os.path.isfile(db_path):
-            raise ValueError("Desired database (='%s') does not "%self.name \
+            raise ValueError("Desired database (='%s') does not " % self.name \
                     + "exist")
         SQLDatabase.__init__(self, db_path, read_only=read_only)
         if self.get_skeleton() != _miniCremonaSkeleton:
-            raise RuntimeError('Database at %s does '%(self.__dblocation__) \
+            raise RuntimeError('Database at %s does ' % (self.__dblocation__) \
               + 'not appear to be a valid SQL Cremona database.')
 
     def __iter__(self):
         """
-        Returns an iterator through all EllipticCurve objects in the
+        Return an iterator through all EllipticCurve objects in the
         Cremona database.
 
         TESTS::
@@ -686,10 +696,10 @@ class MiniCremonaDatabase(SQLDatabase):
         try:
             N = int(N)
         except ValueError:
-            raise KeyError("N (=%s) must be a string or positive integer."%N)
+            raise KeyError("N (=%s) must be a string or positive integer." % N)
 
         if N <= 0:
-            raise KeyError("N (=%s) must be a string or positive integer."%N)
+            raise KeyError("N (=%s) must be a string or positive integer." % N)
 
         ret = {'allcurves': self.allcurves(N)}
         if hasattr(self, 'allbsd'):
@@ -715,7 +725,7 @@ class MiniCremonaDatabase(SQLDatabase):
 
     def allcurves(self, N):
         """
-        Returns the allcurves table of curves of conductor N.
+        Return the allcurves table of curves of conductor N.
 
         INPUT:
 
@@ -738,14 +748,14 @@ class MiniCremonaDatabase(SQLDatabase):
         ret = {}
         for c in self.__connection__.cursor().execute('SELECT curve,eqn,' \
             + 'rank,tors FROM t_curve,t_class USING(class) WHERE ' \
-            + 'conductor=?',(int(N),)):
+            + 'conductor=?', (int(N),)):
             N,iso,num = parse_cremona_label(c[0])
-            ret[iso+str(num)] = [eval(c[1]),c[2],c[3]]
+            ret[iso+str(num)] = [eval(c[1]), c[2], c[3]]
         return ret
 
     def curves(self, N):
         """
-        Returns the curves table of all *optimal* curves of conductor N.
+        Return the curves table of all *optimal* curves of conductor N.
 
         INPUT:
 
@@ -808,8 +818,6 @@ class MiniCremonaDatabase(SQLDatabase):
 
             sage: 'gens' in CremonaDatabase().coefficients_and_data('100467a2')[1] # optional - database_cremona_ellcurve
             True
-
-
         """
         # There are two possible strings: the Cremona label and the LMFDB label.
         # They are distinguished by the presence of a period.
@@ -909,8 +917,8 @@ class MiniCremonaDatabase(SQLDatabase):
 
     def elliptic_curve_from_ainvs(self, ainvs):
         """
-        Returns the elliptic curve in the database of with minimal
-        ainvs, if it exists, or raises a RuntimeError exception
+        Return the elliptic curve in the database of with minimal
+        ``ainvs``, if it exists, or raises a ``RuntimeError`` exception
         otherwise.
 
         INPUT:
@@ -1038,7 +1046,7 @@ class MiniCremonaDatabase(SQLDatabase):
 
     def isogeny_class(self, label):
         """
-        Returns the isogeny class of elliptic curves that are
+        Return the isogeny class of elliptic curves that are
         isogenous to the curve with given Cremona label.
 
         INPUT:
@@ -1059,14 +1067,15 @@ class MiniCremonaDatabase(SQLDatabase):
             sage: c.isogeny_class('12001a1')   # optional - database_cremona_ellcurve
             [Elliptic Curve defined by y^2 + x*y = x^3 - 101*x + 382 over Rational Field]
         """
-        conductor,iso,num=parse_cremona_label(label)
+        conductor, iso, num = parse_cremona_label(label)
         q = self.__connection__.cursor().execute("SELECT curve FROM t_curve " \
             + "WHERE class=?",(str(conductor)+iso,))
         return [self.elliptic_curve(c[0]) for c in q]
 
     def iter_optimal(self, conductors):
         """
-        Return an iterator through all optimal curves in the database with given conductors.
+        Return an iterator through all optimal curves in the database
+        with given conductors.
 
         INPUT:
 
@@ -1104,7 +1113,7 @@ class MiniCremonaDatabase(SQLDatabase):
 
     def list(self, conductors):
         """
-        Returns a list of all curves with given conductors.
+        Return a list of all curves with given conductors.
 
         INPUT:
 
@@ -1126,7 +1135,7 @@ class MiniCremonaDatabase(SQLDatabase):
 
     def list_optimal(self, conductors):
         """
-        Returns a list of all optimal curves with given conductors.
+        Return a list of all optimal curves with given conductors.
 
         INPUT:
 
@@ -1161,7 +1170,6 @@ class MiniCremonaDatabase(SQLDatabase):
         """
         if hasattr(self, '__largest_conductor__'):
             return self.__largest_conductor__
-        #print "Computing largest conductor."
         q = self.__connection__.cursor().execute('SELECT conductor FROM ' \
             + 't_class ORDER BY conductor DESC LIMIT 1')
         self.__largest_conductor__ = next(q)[0]
@@ -1177,10 +1185,10 @@ class MiniCremonaDatabase(SQLDatabase):
 
         .. note::
 
-           This always returns the integer 1, since that is the
-           smallest conductor for which the database is complete,
-           although there are no elliptic curves of conductor 1.  The
-           smallest conductor of a curve in the database is 11.
+            This always returns the integer 1, since that is the
+            smallest conductor for which the database is complete,
+            although there are no elliptic curves of conductor 1.  The
+            smallest conductor of a curve in the database is 11.
 
         EXAMPLES::
 
@@ -1206,7 +1214,7 @@ class MiniCremonaDatabase(SQLDatabase):
 
     def number_of_curves(self,  N=0, i=0):
         """
-        Returns the number of curves stored in the database with conductor
+        Return the number of curves stored in the database with conductor
         N. If N = 0, returns the total number of curves in the database.
 
         If i is nonzero, returns the number of curves in the i-th isogeny
@@ -1251,7 +1259,7 @@ class MiniCremonaDatabase(SQLDatabase):
 
     def number_of_isogeny_classes(self, N=0):
         """
-        Returns the number of isogeny classes of curves in the database of
+        Return the number of isogeny classes of curves in the database of
         conductor N. If N is 0, return the total number of isogeny classes
         of curves in the database.
 
@@ -1283,7 +1291,7 @@ class MiniCremonaDatabase(SQLDatabase):
 
     def random(self):
         """
-        Returns a random curve from the database.
+        Return a random curve from the database.
 
         EXAMPLES::
 
@@ -1406,6 +1414,7 @@ class MiniCremonaDatabase(SQLDatabase):
             if largest_conductor and int(N) > largest_conductor: break
         return num_curves, num_iso_classes
 
+
 class LargeCremonaDatabase(MiniCremonaDatabase):
     """
     The Cremona database of elliptic curves.
@@ -1440,11 +1449,11 @@ class LargeCremonaDatabase(MiniCremonaDatabase):
                     skeleton=_cremonaSkeleton)
             return
         if not os.path.isfile(db_path):
-            raise ValueError("Desired database (='%s') does not "%self.name \
+            raise ValueError("Desired database (='%s') does not " % self.name \
                     + "exist")
         SQLDatabase.__init__(self, db_path, read_only=read_only)
         if self.get_skeleton() != _cremonaSkeleton:
-            raise RuntimeError('Database at %s does '%(self.__dblocation__) \
+            raise RuntimeError('Database at %s does ' % (self.__dblocation__) \
               + 'not appear to be a valid SQL Cremona database.')
 
     def allbsd(self, N):
@@ -1642,7 +1651,10 @@ class LargeCremonaDatabase(MiniCremonaDatabase):
             print("Committing...")
             if largest_conductor and int(v[0]) > largest_conductor: break
 
+
 _db = None
+
+
 def CremonaDatabase(name=None,mini=None,set_global=None):
     """
     Initializes the Cremona database with name ``name``. If ``name`` is
