@@ -402,6 +402,14 @@ class Mathematica(ExtraTabCompletion, Expect):
     """
     def __init__(self, maxread=None, script_subdirectory=None, logfile=None, server=None,
                  server_tmpdir=None, command=None, verbose_start=False):
+        r"""
+        TESTS:
+
+        Test that :trac:`28075` is fixed::
+
+            sage: repr(mathematica.eval("Print[1]; Print[2]; Print[3]"))  # optional - mathematica
+            '1\n2\n3'
+        """
         # We use -rawterm to get a raw text interface in Mathematica 9 or later.
         # This works around the following issues of Mathematica 9 or later
         # (tested with Mathematica 11.0.1 for Mac OS X x86 (64-bit))
@@ -426,13 +434,14 @@ class Mathematica(ExtraTabCompletion, Expect):
         else:
             command = 'sh -c "stty -echo; {}"'.format(command)
         Expect.__init__(self,
-                        name = 'mathematica',
-                        command = command,
-                        prompt = 'In[[0-9]+]:=',
-                        server = server,
-                        server_tmpdir = server_tmpdir,
-                        script_subdirectory = script_subdirectory,
-                        verbose_start = verbose_start,
+                        name='mathematica',
+                        terminal_echo=False,
+                        command=command,
+                        prompt=r'In\[[0-9]+\]:= ',
+                        server=server,
+                        server_tmpdir=server_tmpdir,
+                        script_subdirectory=script_subdirectory,
+                        verbose_start=verbose_start,
                         logfile=logfile,
                         eval_using_file_cutoff=eval_using_file_cutoff)
 
@@ -842,7 +851,7 @@ class MathematicaElement(ExpectElement):
         AUTHORS:
         - Felix Lawrence (2009-08-21)
         """
-        return self.Length()
+        return int(self.Length())
 
     @cached_method
     def _is_graphics(self):
