@@ -195,42 +195,42 @@ def test_executable(args, input="", timeout=100.0, **kwds):
         sage: ret
         0
 
-        sage: (out, err, ret) = test_executable(["sage", "--root"])
-        sage: len(out) >= 2   # at least one character + newline
+        sage: (out, err, ret) = test_executable(["sage", "--root"])  # optional - build
+        sage: len(out) >= 2   # at least one character + newline; optional - build
         True
-        sage: err
+        sage: err  # optional - build
         ''
-        sage: ret
+        sage: ret  # optional -build
         0
 
     Test ``sage --info [packages]`` and the equivalent
     ``sage -p --info --info [packages]`` (the doubling of ``--info``
     is intentional, that option should be idempotent)::
 
-        sage: out, err, ret = test_executable(["sage", "--info", "sqlite"])
-        sage: print(out)
+        sage: out, err, ret = test_executable(["sage", "--info", "sqlite"])  # optional - build
+        sage: print(out)  # optional - build
         Found local metadata for sqlite-...
         = SQLite =
         ...
         SQLite is a software library that implements a self-contained,
         serverless, zero-configuration, transactional SQL database engine.
         ...
-        sage: err
+        sage: err  # optional - build
         ''
-        sage: ret
+        sage: ret  # optional - build
         0
 
-        sage: out, err, ret = test_executable(["sage", "-p", "--info", "--info", "sqlite"])
-        sage: print(out)
+        sage: out, err, ret = test_executable(["sage", "-p", "--info", "--info", "sqlite"])  # optional - build
+        sage: print(out)  # optional - build
         Found local metadata for sqlite-...
         = SQLite =
         ...
         SQLite is a software library that implements a self-contained,
         serverless, zero-configuration, transactional SQL database engine.
         ...
-        sage: err
+        sage: err  # optional - build
         ''
-        sage: ret
+        sage: ret  # optional - build
         0
 
     Test ``sage-run`` on a Python file, both with an absolute and with a relative path::
@@ -261,7 +261,7 @@ def test_executable(args, input="", timeout=100.0, **kwds):
         sage: dir = tmp_dir(); name = 'sage_test_file.sage'
         sage: fullname = os.path.join(dir, name)
         sage: F = open(fullname, 'w')
-        sage: _ = F.write("k.<a> = GF(5^3); print(a^124)\n")
+        sage: _ = F.write("from __future__ import print_function\nk.<a> = GF(5^3); print(a^124)\n")
         sage: F.close()
         sage: (out, err, ret) = test_executable(["sage", fullname])
         sage: print(out)
@@ -353,7 +353,7 @@ def test_executable(args, input="", timeout=100.0, **kwds):
     Test ``sage -t --debug -p 2`` on a ReST file, the ``-p 2`` should
     be ignored. In Pdb, we run the ``help`` command::
 
-        sage: s = "::\n\n    sage: assert True == False\n    sage: 2 + 2\n    5"
+        sage: s = "::\n\n    sage: assert True is False\n    sage: 2 + 2\n    5"
         sage: script = tmp_filename(ext='.rst')
         sage: F = open(script, 'w')
         sage: _ = F.write(s)
@@ -368,13 +368,13 @@ def test_executable(args, input="", timeout=100.0, **kwds):
         **********************************************************************
         File "...", line 3, in ...
         Failed example:
-            assert True == False
+            assert True is False
         Exception raised:
             Traceback (most recent call last):
             ...
             AssertionError
         > <doctest ...>(1)<module>()
-        -> assert True == False
+        -> assert True is False
         (Pdb)
         Documented commands (type help <topic>):
         ========================================
@@ -389,7 +389,7 @@ def test_executable(args, input="", timeout=100.0, **kwds):
             4
         **********************************************************************
         Previously executed commands:
-            s...: assert True == False
+            s...: assert True is False
         sage:
         <BLANKLINE>
         Returning to doctests...
